summaryrefslogtreecommitdiff
path: root/ext/msession
diff options
context:
space:
mode:
authorMark L. Woodward <mlwmohawk@php.net>2001-12-23 02:22:09 +0000
committerMark L. Woodward <mlwmohawk@php.net>2001-12-23 02:22:09 +0000
commitc20deee43d57775243165cb3166ce6d85b2c825e (patch)
tree91e8199a2642f8a91a67e956e705d308aa178246 /ext/msession
parentb498ec567cb76403885da8cb79016787dff2d1a5 (diff)
downloadphp-git-c20deee43d57775243165cb3166ce6d85b2c825e.tar.gz
Renamed msession_getdata and msession_setdata to
msession_get_data and msession_set_data respectively.
Diffstat (limited to 'ext/msession')
-rw-r--r--ext/msession/README5
-rw-r--r--ext/msession/msession.c14
-rw-r--r--ext/msession/php_msession.h4
3 files changed, 14 insertions, 9 deletions
diff --git a/ext/msession/README b/ext/msession/README
index d089d23008..8d793ca606 100644
--- a/ext/msession/README
+++ b/ext/msession/README
@@ -15,3 +15,8 @@ is probably wrong.
You will need phoenix installed and built to compile this
module.
+
+12/22/2001
+Changed msession_getdata(...) to msession_get_data(...)
+Changed msession_setdata(...) to msession_set_data(...)
+(docs to follow)
diff --git a/ext/msession/php_msession.h b/ext/msession/php_msession.h
index 04736f07ee..c457b1aadd 100644
--- a/ext/msession/php_msession.h
+++ b/ext/msession/php_msession.h
@@ -54,8 +54,8 @@ PHP_FUNCTION(msession_get_array);
PHP_FUNCTION(msession_set_array);
PHP_FUNCTION(msession_timeout);
PHP_FUNCTION(msession_inc);
-PHP_FUNCTION(msession_setdata);
-PHP_FUNCTION(msession_getdata);
+PHP_FUNCTION(msession_set_data);
+PHP_FUNCTION(msession_get_data);
PHP_FUNCTION(msession_listvar);
PHP_FUNCTION(msession_list);
PHP_FUNCTION(msession_uniq);
diff --git a/ext/msession/msession.c b/ext/msession/msession.c
index c2c9b4ab71..cde3536672 100644
--- a/ext/msession/msession.c
+++ b/ext/msession/msession.c
@@ -31,7 +31,7 @@
/*
* Please do not remove backward compatibility from this module.
- * this same souce must also work with 4.0 versions of PHP.
+ * this same source must also work with 4.0 versions of PHP.
*
* Also, please to not reformat braces ;-)
* -MLW
@@ -92,8 +92,8 @@ function_entry msession_functions[] = {
PHP_FE(msession_set_array,NULL)
PHP_FE(msession_timeout,NULL)
PHP_FE(msession_inc,NULL)
- PHP_FE(msession_setdata,NULL)
- PHP_FE(msession_getdata,NULL)
+ PHP_FE(msession_set_data,NULL)
+ PHP_FE(msession_get_data,NULL)
PHP_FE(msession_listvar,NULL)
PHP_FE(msession_list,NULL)
PHP_FE(msession_uniq,NULL)
@@ -1107,9 +1107,9 @@ PHP_FUNCTION(msession_inc)
}
/* }}} */
-/* {{{ proto string msession_getdata(string session)
+/* {{{ proto string msession_get_data(string session)
Get data ... ? */
-PHP_FUNCTION(msession_getdata)
+PHP_FUNCTION(msession_get_data)
{
char *val;
zval **session;
@@ -1139,9 +1139,9 @@ PHP_FUNCTION(msession_getdata)
}
/* }}} */
/* {{{ proto bool msession_setdata(string session, string value)
Set data ... ?*/
-PHP_FUNCTION(msession_setdata)
+PHP_FUNCTION(msession_set_data)
{
zval **session;
zval **value;
@@ -1139,9 +1139,9 @@ PHP_FUNCTION(msession_getdata)
}
/* }}} */
-/* {{{ proto bool msession_setdata(string session, string value)
+/* {{{ proto bool msession_set_data(string session, string value)
Set data ... ?*/